Struct pallet_im_online::BoundedOpaqueNetworkState [−][src]
pub struct BoundedOpaqueNetworkState<PeerIdEncodingLimit, MultiAddrEncodingLimit, AddressesLimit> where
PeerIdEncodingLimit: Get<u32>,
MultiAddrEncodingLimit: Get<u32>,
AddressesLimit: Get<u32>, {
pub peer_id: WeakBoundedVec<u8, PeerIdEncodingLimit>,
pub external_addresses: WeakBoundedVec<WeakBoundedVec<u8, MultiAddrEncodingLimit>, AddressesLimit>,
}Expand description
A type that is the same as OpaqueNetworkState but with Vec replaced with
WeakBoundedVec<Limit> where Limit is the respective size limit
PeerIdEncodingLimit represents the size limit of the encoding of PeerId
MultiAddrEncodingLimit represents the size limit of the encoding of MultiAddr
AddressesLimit represents the size limit of the vector of peers connected
Fields
peer_id: WeakBoundedVec<u8, PeerIdEncodingLimit>PeerId of the local node in SCALE encoded.
external_addresses: WeakBoundedVec<WeakBoundedVec<u8, MultiAddrEncodingLimit>, AddressesLimit>List of addresses the node knows it can be reached as.